"""Tests for CaSQ."""

import glob
import os
import unittest.mock

from casq.celldesigner2qual import main
from casq.utils import validate

import pytest  # type: ignore


@pytest.mark.parametrize(
    "infile",
    glob.glob(os.path.join(str(os.path.dirname(os.path.realpath(__file__))), "*.xml")),
)
def test_casq_produces_valid_files(tmp_path, infile):
    """Check if the files we produce are valid."""
    outfile = os.path.join(
        str(tmp_path), os.path.splitext(os.path.basename(infile))[0] + ".sbml"
    )
    with unittest.mock.patch("sys.argv", ["casq", infile, outfile]):
        main()
    assert validate(outfile) == "OK"



"""Various utilities.

Copyright (C) 2019-2021 Sylvain.Soliman@inria.fr

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
import json
import subprocess
import time


def validate(filename: str) -> str:
    """Validate an SBML file using the online validator API.

    Unit consistency verification is off
    """
    url = "http://sbml.org/validator/"
    command = "curl -s -F file=@{filename} -F output=json -F offcheck=u {url}".format(
        filename=filename, url=url
    )
    try:
        process = subprocess.run(command.split(), stdout=subprocess.PIPE, check=True)
    except subprocess.CalledProcessError as e:
        # failure to receive data
        if e.returncode == 56:
            time.sleep(2)
            return validate(filename)
        return e.output
    result = json.loads(process.stdout.decode("utf-8"))["validation-results"]
    if "no-errors" in result:
        return "OK"
    # else:
    return json.dumps(result["problem"], indent=2)



# noqa: D100
# pylint: disable=missing-docstring
from setuptools import find_packages, setup  # type: ignore

with open("README.rst", "r") as file:
    README = file.read()

with open("casq/__init__.py", "r") as file:
    for line in file.readlines():
        if line.startswith("version ="):
            version = line.split('"')[1]

setup(
    name="casq",
    version=version,
    description="CaSQ: Celldesigner as Sbml-Qual",
    long_description=README,
    long_description_content_type="text/x-rst",
    url="https://lifeware.inria.fr/~soliman/post/casq/",
    project_urls={
        "Documentation": "https://readthedocs.org/projects/casq/",
        "Code": "https://gitlab.inria.fr/soliman/casq/",
        "Mirror": "https://github.com/soli/casq",
    },
    license="GPLv3",
    packages=find_packages(),
    author="Sylvain Soliman",
    author_email="Sylvain.Soliman@inria.fr",
    install_requires=["networkx>=2.2", "loguru>=0.2.5"],
    python_requires=">=3.5",
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
    extras_require={"dev": ["black", "check-manifest", "flake8-mypy"]},
    include_package_data=True,
    zip_safe=False,
    entry_points={"console_scripts": ["casq = casq.celldesigner2qual:main"]},
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
)
